Get a Role-specific System Prompt
Examples
if (FALSE) { # \dontrun{
# Convenience helper to get role prompts from the Logic Registry
register_role("assistant", "You are a helpful assistant.")
p <- get_role_prompt("assistant")
} # }
Get a Role-specific System Prompt
if (FALSE) { # \dontrun{
# Convenience helper to get role prompts from the Logic Registry
register_role("assistant", "You are a helpful assistant.")
p <- get_role_prompt("assistant")
} # }