A high-level helper that performs a comprehensive check on a YAML/JSON workflow file. This includes schema validation, topological consistency checks (Mermaid vs YAML), and R logic syntax linting.
A high-level helper that performs a comprehensive check on a YAML/JSON workflow file. This includes schema validation, topological consistency checks (Mermaid vs YAML), and R logic syntax linting.